@@ -431,6 +431,9 @@ class SuperDateTime:
         else:
             raise Exception("data_type is not supported")
 
+    def __sub__(self, other):
+        return self.value - other.value
+
     @property
     def value(self):
         """
